Public configuration models used by the plan and apply pipeline.
Structs
- Apply
Settings - Settings for the apply pipeline.
- Plan
Settings - Settings for the plan pipeline.
Enums
- RunMode
- Run mode controls exit-code semantics.
Public configuration models used by the plan and apply pipeline.